@@ -12,13 +12,14 @@ Usage::
     session_client: ForecastQueryServiceClient = session.client("forecastquery")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from __future__ import annotations
-
-from typing import Any, Dict
+from typing import Any, Dict, TYPE_CHECKING
 from botocore.exceptions import ClientError as Boto3ClientError
 
 # pylint: disable=import-self
-import mypy_boto3_forecastquery.client as client_scope
+if TYPE_CHECKING:
+    import mypy_boto3_forecastquery.client as client_scope
+else:
+    client_scope = object
 from mypy_boto3_forecastquery.type_defs import ClientQueryForecastResponseTypeDef
 
 
@@ -27,14 +28,14 @@ __all__ = ("ForecastQueryServiceClient",)
 
 class ForecastQueryServiceClient:
     """
-    [ForecastQueryService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.0/reference/services/forecastquery.html#ForecastQueryService.Client)
+    [ForecastQueryService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.7/reference/services/forecastquery.html#ForecastQueryService.Client)
     """
 
-    exceptions: client_scope.Exceptions
+    exceptions: "client_scope.Exceptions"
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.0/reference/services/forecastquery.html#ForecastQueryService.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.7/reference/services/forecastquery.html#ForecastQueryService.Client.can_paginate)
         """
 
     def generate_presigned_url(
@@ -45,7 +46,7 @@ class ForecastQueryServiceClient:
         HttpMethod: str = None,
     ) -> None:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.0/reference/services/forecastquery.html#ForecastQueryService.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.7/reference/services/forecastquery.html#ForecastQueryService.Client.generate_presigned_url)
         """
 
     def query_forecast(
@@ -57,7 +58,7 @@ class ForecastQueryServiceClient:
         NextToken: str = None,
     ) -> ClientQueryForecastResponseTypeDef:
         """
-        [Client.query_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.0/reference/services/forecastquery.html#ForecastQueryService.Client.query_forecast)
+        [Client.query_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.7/reference/services/forecastquery.html#ForecastQueryService.Client.query_forecast)
         """
 
 
